@@ -1,3 +1,25 @@
+//
+// Mainwindow.h
+//
+// Copyright 2012, 2013 by John Pietrzak
+//
+// This file contains the main window declaration for Pierogi.
+//
+// Pierogi is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public License
+// as published by the Free Software Foundation; either version 2
+// of the License, or (at your option) any later version.
+//
+// Pierogi is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software Foundation,
+// Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+//
+
 #ifndef MAINWINDOW_H
 #define MAINWINDOW_H
 
@@ -172,6 +194,11 @@ public:
 
   void gotoNextTabs();
 */
+  void setCarrierFrequency(
+    unsigned int freq);
+
+  void setDutyCycle(
+    unsigned int dc);
 
 signals:
   void buttonPressed(
